@@ -23,14 +23,14 @@ from tests.fixtures import *
 
 @pytest.fixture()
 def pear(client) -> Pear:
-    project = client.get_project("LoadTesting")
+    project = client.get_project(PROJECT_NAME)
     return Pear(project, "my_pear_component")
 
 
 def test_get_parameter(pear, requests_mock):
     configuration = {"param0": "value0", "param1": "value1"}
     requests_mock.get(
-        f"{API_EXPERIMENTAL}/textanalysis/projects/LoadTesting/pearComponents/{pear.identifier}",
+        f"{API_EXPERIMENTAL}/textanalysis/projects/{PROJECT_NAME}/pearComponents/{pear.identifier}",
         json={
             "payload": configuration,
             "errorMessages": [],
